match_template!() { /* proc-macro */ }Expand description
A procedural macro that generates repeated match arms by pattern.
See the module-level documentation for more details.
match_template!() { /* proc-macro */ }A procedural macro that generates repeated match arms by pattern.
See the module-level documentation for more details.